@@ -272,7 +272,7 @@ EXPORT BOOL scg_yes(char *msg)
 {
 	char okbuf[10];
 
-	js_printf("%s", msg);
+	printf("%s", msg);
 	flush();
 	if (s_getline(okbuf, sizeof(okbuf)) == EOF)
 		exit(EX_BAD);
@@ -286,10 +286,10 @@ EXPORT BOOL scg_yes(char *msg)
 #ifdef	nonono
 LOCAL void scg_sighandler(int sig)
 {
-	js_printf("\n");
+	printf("\n");
 	if (scsi_running) {
-		js_printf("Running command: %s\n", scsi_command);
-		js_printf("Resetting SCSI - Bus.\n");
+		printf("Running command: %s\n", scsi_command);
+		printf("Resetting SCSI - Bus.\n");
 		if (scg_reset(scgp) < 0)
 			errmsg("Cannot reset SCSI - Bus.\n");
 	}
@@ -350,15 +350,15 @@ EXPORT int scg_cmd(SCSI *scgp)
 		 * Old /dev/scg versions will not allow to access targets > 7.
 		 * Include a workaround to make this non fatal.
 		 */
-		if (scg_target(scgp) < 8 || geterrno() != EINVAL)
+		if (scg_target(scgp) < 8 || errno != EINVAL)
 			comerr("Cannot send SCSI cmd via ioctl\n");
 		if (scmd->ux_errno == 0)
-			scmd->ux_errno = geterrno();
+			scmd->ux_errno = errno;
 		if (scmd->error == SCG_NO_ERROR)
 			scmd->error = SCG_FATAL;
 		if (scgp->debug > 0) {
 			errmsg("ret < 0 errno: %d ux_errno: %d error: %d\n",
-					geterrno(), scmd->ux_errno, scmd->error);
+					errno, scmd->ux_errno, scmd->error);
 		}
 	}
 
@@ -388,7 +388,7 @@ EXPORT int scg_svhead(SCSI *scgp, char *buf, int maxcnt)
 	if (scgp->verbose <= 0)
 		return (0);
 
-	amt = js_snprintf(p, maxcnt,
+	amt = snprintf(p, maxcnt,
 		"\nExecuting '%s' command on Bus %d Target %d, Lun %d timeout %ds\n",
 								/* XXX Really this ??? */
 /*		scgp->cmdname, scg_scsibus(scgp), scg_target(scgp), scgp->scmd->cdb.g0_cdb.lun,*/
@@ -458,13 +458,13 @@ EXPORT int scg_svtail(SCSI *scgp, int *retp, char *buf, int maxcnt)
 			 * A DMA residual count < 0 (-1) is a hint for a DMA
 			 * overrun but does not affect the transfer count.
 			 */
-			amt = js_snprintf(p, maxcnt, "DMA overrun, ");
+			amt = snprintf(p, maxcnt, "DMA overrun, ");
 			if (amt < 0)
 				return (amt);
 			p += amt;
 			maxcnt -= amt;
 		}
-		amt = js_snprintf(p, maxcnt, "resid: %d\n", scgp->scmd->resid);
+		amt = snprintf(p, maxcnt, "resid: %d\n", scgp->scmd->resid);
 		if (amt < 0)
 			return (amt);
 		p += amt;
@@ -628,14 +628,14 @@ EXPORT int scg__sprinterr(SCSI *scgp, char *buf, int maxcnt)
 				 * We need to cast timeval->* to long because
 				 * of the broken sys/time.h in Linux.
 				 */
-	case SCG_TIMEOUT  :	js_snprintf(errbuf, sizeof(errbuf),
+	case SCG_TIMEOUT  :	snprintf(errbuf, sizeof(errbuf),
 					"cmd timeout after %ld.%03ld (%d) s",
 					(long)scgp->cmdstop->tv_sec,
 					(long)scgp->cmdstop->tv_usec/1000,
 								cp->timeout);
 				err = errbuf;
 				break;
-	default:		js_snprintf(errbuf, sizeof(errbuf),
+	default:		snprintf(errbuf, sizeof(errbuf),
 					"error: %d", cp->error);
 				err = errbuf;
 	}
@@ -716,7 +716,7 @@ EXPORT void scg_printwdata(SCSI *scgp)
 	register struct	scg_cmd	*scmd = scgp->scmd;
 
 	if (scmd->size > 0 && (scmd->flags & SCG_RECV_DATA) == 0) {
-		js_fprintf(stderr, "Sending %d (0x%X) bytes of data.\n",
+		fprintf(stderr, "Sending %d (0x%X) bytes of data.\n",
 			scmd->size, scmd->size);
 		scg_prbytes("Write Data: ",
 			(Uchar *)scmd->addr,
@@ -734,7 +734,7 @@ EXPORT int scg_sprintwdata(SCSI *scgp, char *buf, int maxcnt)
 	register int		amt;
 
 	if (scmd->size > 0 && (scmd->flags & SCG_RECV_DATA) == 0) {
-		amt = js_snprintf(p, maxcnt,
+		amt = snprintf(p, maxcnt,
 			"Sending %d (0x%X) bytes of data.\n",
 			scmd->size, scmd->size);
 		if (amt < 0)
@@ -762,7 +762,7 @@ EXPORT void scg_printrdata(SCSI *scgp)
 	register int		trcnt = scg_getdmacnt(scgp);
 
 	if (scmd->size > 0 && (scmd->flags & SCG_RECV_DATA) != 0) {
-		js_fprintf(stderr, "Got %d (0x%X), expecting %d (0x%X) bytes of data.\n",
+		fprintf(stderr, "Got %d (0x%X), expecting %d (0x%X) bytes of data.\n",
 			trcnt, trcnt,
 			scmd->size, scmd->size);
 		scg_prbytes("Received Data: ",
@@ -782,7 +782,7 @@ EXPORT int scg_sprintrdata(SCSI *scgp, char *buf, int maxcnt)
 	register int		trcnt = scg_getdmacnt(scgp);
 
 	if (scmd->size > 0 && (scmd->flags & SCG_RECV_DATA) != 0) {
-		amt = js_snprintf(p, maxcnt,
+		amt = snprintf(p, maxcnt,
 			"Got %d (0x%X), expecting %d (0x%X) bytes of data.\n",
 			trcnt, trcnt,
 			scmd->size, scmd->size);
@@ -808,7 +808,7 @@ EXPORT int scg_sprintrdata(SCSI *scgp, char *buf, int maxcnt)
  */
 EXPORT void scg_printresult(SCSI *scgp)
 {
-	js_fprintf(stderr, "cmd finished after %ld.%03lds timeout %ds\n",
+	fprintf(stderr, "cmd finished after %ld.%03lds timeout %ds\n",
 		(long)scgp->cmdstop->tv_sec,
 		(long)scgp->cmdstop->tv_usec/1000,
 		scgp->scmd->timeout);
@@ -825,7 +825,7 @@ EXPORT int scg_sprintresult(SCSI *scgp, char *buf, int maxcnt)
 	register char		*p = buf;
 	register int		amt;
 
-	amt = js_snprintf(p, maxcnt,
+	amt = snprintf(p, maxcnt,
 		"cmd finished after %ld.%03lds timeout %ds\n",
 		(long)scgp->cmdstop->tv_sec,
 		(long)scgp->cmdstop->tv_usec/1000,
@@ -871,21 +871,21 @@ EXPORT int scg_sprintstatus(SCSI *scgp, char *buf, int maxcnt)
 	register char	*p = buf;
 	register int	amt;
 
-	amt = js_snprintf(p, maxcnt, "status: 0x%x ", *(Uchar *)&cp->scb);
+	amt = snprintf(p, maxcnt, "status: 0x%x ", *(Uchar *)&cp->scb);
 	if (amt < 0)
 		return (amt);
 	p += amt;
 	maxcnt -= amt;
 #ifdef	SCSI_EXTENDED_STATUS
 	if (cp->scb.ext_st1) {
-		amt = js_snprintf(p, maxcnt, "0x%x ", ((Uchar *)&cp->scb)[1]);
+		amt = snprintf(p, maxcnt, "0x%x ", ((Uchar *)&cp->scb)[1]);
 		if (amt < 0)
 			return (amt);
 		p += amt;
 		maxcnt -= amt;
 	}
 	if (cp->scb.ext_st2) {
-		amt = js_snprintf(p, maxcnt, "0x%x ", ((Uchar *)&cp->scb)[2]);
+		amt = snprintf(p, maxcnt, "0x%x ", ((Uchar *)&cp->scb)[2]);
 		if (amt < 0)
 			return (amt);
 		p += amt;
@@ -907,7 +907,7 @@ EXPORT int scg_sprintstatus(SCSI *scgp, char *buf, int maxcnt)
 	if (cp->scb.ext_st1 && cp->scb.ha_er)
 		err2 = " host adapter detected error";
 #endif
-	amt = js_snprintf(p, maxcnt, "(%s%s)\n", err, err2);
+	amt = snprintf(p, maxcnt, "(%s%s)\n", err, err2);
 	if (amt < 0)
 		return (amt);
 	p += amt;
@@ -919,10 +919,10 @@ EXPORT int scg_sprintstatus(SCSI *scgp, char *buf, int maxcnt)
  */
 EXPORT void scg_fprbytes(FILE *f, char *s, Uchar *cp, int n)
 {
-	js_fprintf(f, s);
+	fprintf(f, s);
 	while (--n >= 0)
-		js_fprintf(f, " %02X", *cp++);
-	js_fprintf(f, "\n");
+		fprintf(f, " %02X", *cp++);
+	fprintf(f, "\n");
 }
 
 /*
@@ -943,20 +943,20 @@ EXPORT int scg_sprbytes(char *buf, int maxcnt, char *s, Uchar *cp, int n)
 	register char	*p = buf;
 	register int	amt;
 
-	amt = js_snprintf(p, maxcnt, s);
+	amt = snprintf(p, maxcnt, s);
 	if (amt < 0)
 		return (amt);
 	p += amt;
 	maxcnt -= amt;
 
 	while (--n >= 0) {
-		amt = js_snprintf(p, maxcnt, " %02X", *cp++);
+		amt = snprintf(p, maxcnt, " %02X", *cp++);
 		if (amt < 0)
 			return (amt);
 		p += amt;
 		maxcnt -= amt;
 	}
-	amt = js_snprintf(p, maxcnt, "\n");
+	amt = snprintf(p, maxcnt, "\n");
 	if (amt < 0)
 		return (amt);
 	p += amt;
@@ -1056,71 +1056,71 @@ EXPORT int scg_sense_qual(SCSI *scgp)
 EXPORT void scg_fprintdev(FILE *f, struct scsi_inquiry *ip)
 {
 	if (ip->removable)
-		js_fprintf(f, "Removable ");
+		fprintf(f, "Removable ");
 	if (ip->data_format >= 2) {
 		switch (ip->qualifier) {
 
 		case INQ_DEV_PRESENT:
 			break;
 		case INQ_DEV_NOTPR:
-			js_fprintf(f, "not present ");
+			fprintf(f, "not present ");
 			break;
 		case INQ_DEV_RES:
-			js_fprintf(f, "reserved ");
+			fprintf(f, "reserved ");
 			break;
 		case INQ_DEV_NOTSUP:
 			if (ip->type == INQ_NODEV) {
-				js_fprintf(f, "unsupported\n"); return;
+				fprintf(f, "unsupported\n"); return;
 			}
-			js_fprintf(f, "unsupported ");
+			fprintf(f, "unsupported ");
 			break;
 		default:
-			js_fprintf(f, "vendor specific %d ", ip->qualifier);
+			fprintf(f, "vendor specific %d ", ip->qualifier);
 		}
 	}
 	switch (ip->type) {
 
 	case INQ_DASD:
-		js_fprintf(f, "Disk");		break;
+		fprintf(f, "Disk");		break;
 	case INQ_SEQD:
-		js_fprintf(f, "Tape");		break;
+		fprintf(f, "Tape");		break;
 	case INQ_PRTD:
-		js_fprintf(f, "Printer");	break;
+		fprintf(f, "Printer");	break;
 	case INQ_PROCD:
-		js_fprintf(f, "Processor");	break;
+		fprintf(f, "Processor");	break;
 	case INQ_WORM:
-		js_fprintf(f, "WORM");		break;
+		fprintf(f, "WORM");		break;
 	case INQ_ROMD:
-		js_fprintf(f, "CD-ROM");	break;
+		fprintf(f, "CD-ROM");	break;
 	case INQ_SCAN:
-		js_fprintf(f, "Scanner");	break;
+		fprintf(f, "Scanner");	break;
 	case INQ_OMEM:
-		js_fprintf(f, "Optical Storage");break;
+		fprintf(f, "Optical Storage");break;
 	case INQ_JUKE:
-		js_fprintf(f, "Juke Box");	break;
+		fprintf(f, "Juke Box");	break;
 	case INQ_COMM:
-		js_fprintf(f, "Communication");	break;
+		fprintf(f, "Communication");	break;
 	case INQ_IT8_1:
-		js_fprintf(f, "IT8 1");		break;
+		fprintf(f, "IT8 1");		break;
 	case INQ_IT8_2:
-		js_fprintf(f, "IT8 2");		break;
+		fprintf(f, "IT8 2");		break;
 	case INQ_STARR:
-		js_fprintf(f, "Storage array");	break;
+		fprintf(f, "Storage array");	break;
 	case INQ_ENCL:
-		js_fprintf(f, "Enclosure services");break;
+		fprintf(f, "Enclosure services");break;
 
 	case INQ_NODEV:
 		if (ip->data_format >= 2) {
-			js_fprintf(f, "unknown/no device");
+			fprintf(f, "unknown/no device");
 			break;
 		} else if (ip->qualifier == INQ_DEV_NOTSUP) {
-			js_fprintf(f, "unit not present");
+			fprintf(f, "unit not present");
 			break;
 		}
 	default:
-		js_fprintf(f, "unknown device type 0x%x", ip->type);
+		fprintf(f, "unknown device type 0x%x", ip->type);
 	}
-	js_fprintf(f, "\n");
+	fprintf(f, "\n");
 }
 
 /*
