@@ -31,7 +31,7 @@ _niwrite(f, buf, count)
 {
 	int ret;
  
-	while((ret = write(f, buf, count)) < 0 && geterrno() == EINTR)
+	while((ret = write(f, buf, count)) < 0 && errno == EINTR)
 		;
 	return(ret);
 }
